==> kImageAnnotator-0.4.1.tar.gz: kImageAnnotator-0.4.1/translations/kImageAnnotator_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>kImageAnnotator::AnnotationContextMenu</name>
    <message>
        <source>Arrange</source>
        <translation>Organizar</translation>
    </message>
    <message>
        <source>Bring to Front</source>
        <translation>Trazer para frente</translation>
    </message>
    <message>
        <source>Bring Forward</source>
        <translation>Avançar um nível</translation>
    </message>
    <message>
        <source>Send Backward</source>
        <translation>Recuar um nível</translation>
    </message>
    <message>
        <source>Send to Back</source>
        <translation>Enviar para trás</translation>
    </message>
    <message>
        <source>Select This</source>
        <translation>Selecione isto</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Colar</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Apagar</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationSettings</name>
    <message>
        <source>Color</source>
        <translation>Cor</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Tamanho / Espessura da Ferramenta atual</translation>
    </message>
    <message>
        <source>Text Color</source>
        <translation>Cor do texto</translation>
    </message>
    <message>
        <source>Font Size</source>
        <translation>Tamanho da fonte</translation>
    </message>
    <message>
        <source>Starting Number</source>
        <translation>Número inicial</translation>
    </message>
    <message>
        <source>Obfuscation Factor</source>
        <translation>Fator de ofuscamento</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationTabContextMenu</name>
    <message>
        <source>Close</source>
        <translation>Fechar aba</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>Fechar outras abas</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Fechar todas as abas</translation>
    </message>
    <message>
        <source>Close All to the Left</source>
        <translation>Fechar abas à esquerda</translation>
    </message>
    <message>
        <source>Close All to the Right</source>
        <translation>Fechar abas à direita</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CropWidget</name>
    <message>
        <source>Crop</source>
        <translation>Recortar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>Largura:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>Altura:</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FillModePicker</name>
    <message>
        <source>Border And Fill Visibility</source>
        <translation>Exibição de borda e preenchimento</translation>
    </message>
    <message>
        <source>Border and Fill</source>
        <translation>Com borda e com preenchimento</translation>
    </message>
    <message>
        <source>Border and No Fill</source>
        <translation>Com borda e sem preenchimento</translation>
    </message>
    <message>
        <source>No Border and No Fill</source>
        <translation>Sem borda e sem preenchimento</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ImageEffectPicker</name>
    <message>
        <source>Image Effects</source>
        <translation>Efeitos da imagem</translation>
    </message>
    <message>
        <source>No Effect</source>
        <translation>Sem efeito</translation>
    </message>
    <message>
        <source>Drop Shadow</source>
        <translation>Sombreado</translation>
    </message>
    <message>
        <source>Grayscale</source>
        <translation>Escala de cinza</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Borda</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ScaleDialog</name>
    <message>
        <source>Scale Image</source>
        <translation>Redimensionar imagem</translation>
    </message>
    <message>
        <source>Keep Aspect Ratio</source>
        <translation>Manter proporção</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Largura:</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Altura:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Pixel</source>
        <translation>Pixel</translation>
    </message>
    <message>
        <source>Percent</source>
        <translation>Porcentagem</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::StickerPicker</name>
    <message>
        <source>Sticker</source>
        <translation>Adesivo</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ToolPicker</name>
    <message>
        <source>Select</source>
        <translation>Seleção</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Caneta</translation>
    </message>
    <message>
        <source>Number</source>
        <translation>Número</translation>
    </message>
    <message>
        <source>Marker Rectangle</source>
        <translation>Marcador Retangular</translation>
    </message>
    <message>
        <source>Marker Ellipse</source>
        <translation>Marcador Elíptico</translation>
    </message>
    <message>
        <source>Marker Pen</source>
        <translation>Caneta Marcadora</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Texto</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Seta</translation>
    </message>
    <message>
        <source>Double Arrow</source>
        <translation>Seta Dupla</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Linha</translation>
    </message>
    <message>
        <source>Blur</source>
        <translation>Ofuscar</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Retângulo</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elipse</translation>
    </message>
    <message>
        <source>Number Pointer</source>
        <translation>Número com ponteiro</translation>
    </message>
    <message>
        <source>Sticker</source>
        <translation>Adesivo</translation>
    </message>
    <message>
        <source>Pixelate</source>
        <translation>Pixelar</translation>
    </message>
    <message>
        <source>Text Pointer</source>
        <translation>Texto com ponteiro</translation>
    </message>
    <message>
        <source>Text Arrow</source>
        <translation>Texto com seta</translation>
    </message>
    <message>
        <source>Number Arrow</source>
        <translation>Número com seta</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ZoomIndicator</name>
    <message>
        <source>Zoom Level</source>
        <translation>Nível de zoom</translation>
    </message>
</context>
</TS>

==> kImageAnnotator-0.6.1.tar.gz: kImageAnnotator-0.6.1/translations/kImageAnnotator_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>kImageAnnotator::AnnotationContextMenu</name>
    <message>
        <source>Arrange</source>
        <translation>Organizar</translation>
    </message>
    <message>
        <source>Bring to Front</source>
        <translation>Trazer para frente</translation>
    </message>
    <message>
        <source>Bring Forward</source>
        <translation>Avançar um nível</translation>
    </message>
    <message>
        <source>Send Backward</source>
        <translation>Recuar um nível</translation>
    </message>
    <message>
        <source>Send to Back</source>
        <translation>Enviar para trás</translation>
    </message>
    <message>
        <source>Select This</source>
        <translation>Selecione isto</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Colar</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Apagar</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationControlsWidget</name>
    <message>
        <source>Controls</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationGeneralSettings</name>
    <message>
        <source>General Settings</source>
        <translation>Configurações Gerais</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationImageSettings</name>
    <message>
        <source>Image Settings</source>
        <translation>Configurações de imagem</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationItemSettings</name>
    <message>
        <source>Color</source>
        <translation>Cor</translation>
    </message>
    <message>
        <source>Text Color</source>
        <translation>Cor do texto</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Tamanho / Espessura da Ferramenta atual</translation>
    </message>
    <message>
        <source>Number Seed</source>
        <translation>Número</translation>
    </message>
    <message>
        <source>Obfuscation Factor</source>
        <translation>Fator de Obfuscação</translation>
    </message>
    <message>
        <source>Item Shadow</source>
        <translation>Sombra do Item</translation>
    </message>
    <message>
        <source>Item Settings</source>
        <translation>Configurações do item</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationTabContextMenu</name>
    <message>
        <source>Close</source>
        <translation>Fechar aba</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>Fechar outras abas</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Fechar todas as abas</translation>
    </message>
    <message>
        <source>Close All to the Left</source>
        <translation>Fechar abas à esquerda</translation>
    </message>
    <message>
        <source>Close All to the Right</source>
        <translation>Fechar abas à direita</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationToolSelection</name>
    <message>
        <source>Tool Selection</source>
        <translation>Seleção de ferramentas</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::BoolPicker</name>
    <message>
        <source>Enabled</source>
        <translation>Ativado</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Desativado</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::Controls</name>
    <message>
        <source>Undo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Redo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Crop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation type="unfinished">Rotacionar</translation>
    </message>
    <message>
        <source>Modify canvas</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cut</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CropWidget</name>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>Largura:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>Altura:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Aplicar</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CutWidget</name>
    <message>
        <source>Vertical</source>
        <translation type="unfinished">Vertical</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation type="unfinished">Horizontal</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation type="unfinished">Aplicar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Cancelar</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FillModePicker</name>
    <message>
        <source>Border And Fill Visibility</source>
        <translation>Exibição de borda e preenchimento</translation>
    </message>
    <message>
        <source>Border and Fill</source>
        <translation>Com borda e com preenchimento</translation>
    </message>
    <message>
        <source>Border and No Fill</source>
        <translation>Com borda e sem preenchimento</translation>
    </message>
    <message>
        <source>No Border and No Fill</source>
        <translation>Sem borda e sem preenchimento</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FontPicker</name>
    <message>
        <source>Font Size</source>
        <translation>Tamanho da fonte</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>Negrito</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>Itálico</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>Sublinhado</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ImageEffectPicker</name>
    <message>
        <source>Image Effects</source>
        <translation>Efeitos da imagem</translation>
    </message>
    <message>
        <source>No Effect</source>
        <translation>Sem efeito</translation>
    </message>
    <message>
        <source>Drop Shadow</source>
        <translation>Sombreado</translation>
    </message>
    <message>
        <source>Grayscale</source>
        <translation>Escala de cinza</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Borda</translation>
    </message>
    <message>
        <source>Invert Color</source>
        <translation>Inverter cor</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ModifyCanvasWidget</name>
    <message>
        <source>Restricted</source>
        <translation>RestritO</translation>
    </message>
    <message>
        <source>When enabled enforces the canvas
to include the background image.</source>
        <translation>Quando ativado, impõe a tela
para incluir a imagem de fundo.</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>Largura:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>Altura:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Aplicar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Cor:</translation>
    </message>
    <message>
        <source>Canvas Background Color</source>
        <translation>Cor de fundo da tela</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::RotateDialog</name>
    <message>
        <source>Rotate Image</source>
        <translation>Rotacionar Imagem</translation>
    </message>
    <message>
        <source>180°</source>
        <translation>180º</translation>
    </message>
    <message>
        <source>90° Clockwise</source>
        <translation>90° no sentido horário</translation>
    </message>
    <message>
        <source>90° Counter Clockwise</source>
        <translation>90° no sentido anti-horário</translation>
    </message>
    <message>
        <source>Arbitrary</source>
        <translation>Arbitrário</translation>
    </message>
    <message>
        <source>Positive values rotate clockwise, negative values counter clockwise.
Rotating by non 90° multipliers might introduce loss of quality.</source>
        <translation>Os valores positivos giram no sentido horário, os valores negativos no sentido anti-horário.
Rotacionar por multiplicadores diferentes de 90° pode causar perda de qualidade.</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Horizontal</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>Vertical</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>Rotacionar</translation>
    </message>
    <message>
        <source>Flip</source>
        <translation>Girar - Inverter</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ScaleDialog</name>
    <message>
        <source>Scale Image</source>
        <translation>Redimensionar imagem</translation>
    </message>
    <message>
        <source>Keep Aspect Ratio</source>
        <translation>Manter proporção</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Largura:</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Altura:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Pixel</source>
        <translation>Pixel</translation>
    </message>
    <message>
        <source>Percent</source>
        <translation>Percentagem</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::StickerPicker</name>
    <message>
        <source>Sticker</source>
        <translation>Adesivo</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ToolPicker</name>
    <message>
        <source>Select</source>
        <translation>Seleção</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Caneta</translation>
    </message>
    <message>
        <source>Number</source>
        <translation>Número</translation>
    </message>
    <message>
        <source>Marker Rectangle</source>
        <translation>Marcador Retangular</translation>
    </message>
    <message>
        <source>Marker Ellipse</source>
        <translation>Marcador Elíptico</translation>
    </message>
    <message>
        <source>Marker Pen</source>
        <translation>Caneta Marcadora</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Texto</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Seta</translation>
    </message>
    <message>
        <source>Double Arrow</source>
        <translation>Seta Dupla</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Linha</translation>
    </message>
    <message>
        <source>Blur</source>
        <translation>Ofuscar</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Retângulo</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elipse</translation>
    </message>
    <message>
        <source>Number Pointer</source>
        <translation>Número com ponteiro</translation>
    </message>
    <message>
        <source>Sticker</source>
        <translation>Adesivo</translation>
    </message>
    <message>
        <source>Pixelate</source>
        <translation>Pixelar</translation>
    </message>
    <message>
        <source>Text Pointer</source>
        <translation>Texto com ponteiro</translation>
    </message>
    <message>
        <source>Text Arrow</source>
        <translation>Texto com seta</translation>
    </message>
    <message>
        <source>Number Arrow</source>
        <translation>Número com seta</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Duplicar</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ZoomPicker</name>
    <message>
        <source>Zoom In (%1)</source>
        <translation>Zoom + (%1)</translation>
    </message>
    <message>
        <source>Zoom Out (%1)</source>
        <translation>Zoom - (%1)</translation>
    </message>
    <message>
        <source>Reset Zoom (%1)</source>
        <translation>Redefinir Zoom (%1)</translation>
    </message>
    <message>
        <source>Reset Zoom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fit Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fit image to view (%1)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
